#
# spec file for package ghc-amazonka-kms
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name amazonka-kms
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.4.3
Release:        7.11
Summary:        Amazon Key Management Service SDK
License:        MPL-2.0
Group:          Development/Languages/Other
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-amazonka-core-devel
BuildRequires:  ghc-rpm-macros
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with tests}
BuildRequires:  ghc-amazonka-test-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-unordered-containers-devel
%endif

%description
AWS Key Management Service AWS Key Management Service (AWS KMS) is an
encryption and key management web service. This guide describes the AWS KMS
operations that you can call programmatically. For general information about
AWS KMS, see the <http://docs.aws.amazon.com/kms/latest/developerguide/ AWS Key
Management Service Developer Guide>. AWS provides SDKs that consist of
libraries and sample code for various programming languages and platforms
(Java, Ruby, .Net, iOS, Android, etc.). The SDKs provide a convenient way to
create programmatic access to AWS KMS and other AWS services. For example, the
SDKs take care of tasks such as signing requests (see below), managing errors,
and retrying requests automatically. For more information about the AWS SDKs,
including how to download and install them, see <http://aws.amazon.com/tools/
Tools for Amazon Web Services>. We recommend that you use the AWS SDKs to make
programmatic API calls to AWS KMS. Clients must support TLS (Transport Layer
Security) 1.0. We recommend TLS 1.2. Clients must also support cipher suites
with Perfect Forward Secrecy (PFS) such as Ephemeral Diffie-Hellman (DHE) or
Elliptic Curve Ephemeral Diffie-Hellman (ECDHE). Most modern systems such as
Java 7 and later support these modes. __Signing Requests__ Requests must be
signed by using an access key ID and a secret access key. We strongly recommend
that you /do not/ use your AWS account access key ID and secret key for
everyday work with AWS KMS. Instead, use the access key ID and secret access
key for an IAM user, or you can use the AWS Security Token Service to generate
temporary security credentials that you can use to sign requests. All AWS KMS
operations require
<http://docs.aws.amazon.com/general/latest/gr/signature-version-4.html
Signature Version 4>. __Logging API Requests__ AWS KMS supports AWS CloudTrail,
a service that logs AWS API calls and related events for your AWS account and
delivers them to an Amazon S3 bucket that you specify. By using the information
collected by CloudTrail, you can determine what requests were made to AWS KMS,
who made the request, when it was made, and so on. To learn more about
CloudTrail, including how to turn it on and find your log files, see the
<http://docs.aws.amazon.com/awscloudtrail/latest/userguide/ AWS CloudTrail User
Guide>. __Additional Resources__ For more information about credentials and
request signing, see the following: -
<http://docs.aws.amazon.com/general/latest/gr/aws-security-credentials.html AWS
Security Credentials> - This topic provides general information about the types
of credentials used for accessing AWS. -
<http://docs.aws.amazon.com/STS/latest/UsingSTS/ AWS Security Token Service> -
This guide describes how to create and use temporary security credentials.
- <http://docs.aws.amazon.com/general/latest/gr/signing_aws_api_requests.html
Signing AWS API Requests> - This set of topics walks you through the process of
signing a request using an access key ID and a secret access key.
__Commonly Used APIs__ Of the APIs discussed in this guide, the following will
prove the most useful for most applications. You will likely perform actions
other than these, such as creating keys and assigning policies, by using the
console. - < Encrypt> - < Decrypt> - < GenerateDataKey> - <
GenerateDataKeyWithoutPlaintext>

The types from this library are intended to be used with
<http://hackage.haskell.org/package/amazonka amazonka>, which provides
mechanisms for specifying AuthN/AuthZ information and sending requests.

Use of lenses is required for constructing and manipulating types.
This is due to the amount of nesting of AWS types and transparency regarding
de/serialisation into more palatable Haskell values. The provided lenses should
be compatible with any of the major lens libraries such as
<http://hackage.haskell.org/package/lens lens> or
<http://hackage.haskell.org/package/lens-family-core lens-family-core>.

See "Network.AWS.KMS" or <https://aws.amazon.com/documentation/ the AWS
Documentation> to get started.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE

%files devel -f %{name}-devel.files
%defattr(-,root,root,-)
%doc README.md

%changelog
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.4.3 revision 0 with cabal2obs.
